pub enum SetupTarget {
Tokf(TokfSetupArgs),
ClaudeCode(DirectHookArgs),
Gemini(DirectHookArgs),
Cursor(DirectHookArgs),
}Variants
Tokf(TokfSetupArgs)
Configure tokf to use rippy as its external permission engine
ClaudeCode(DirectHookArgs)
Install rippy as a direct hook for Claude Code
Gemini(DirectHookArgs)
Install rippy as a direct hook for Gemini CLI
Cursor(DirectHookArgs)
Install rippy as a direct hook for Cursor