detect_git_branch

Function detect_git_branch 

pub fn detect_git_branch(cwd: &Path) -> Option<String>
Detect the current git branch from a working directory.

Returns None if not in a git repository or git is not available.