pub fn evaluate_all(conditions: &[Condition], ctx: &MatchContext<'_>) -> boolExpand description
Evaluate all conditions (AND). Returns true if all pass or list is empty.
pub fn evaluate_all(conditions: &[Condition], ctx: &MatchContext<'_>) -> boolEvaluate all conditions (AND). Returns true if all pass or list is empty.