Module config

Module config 

Structs

Config
Loaded and merged configuration with rules partitioned by type.
ConfigSourceInfo
A config source with its tier label and optional file path.
Rule
A single rule: target + decision + pattern + optional message + conditions.

Enums

ConfigDirective
A parsed config directive — either a Rule, a Set key/value, or an Alias.
ConfigFormat
Format hint for Config::load_from_str.
RuleTarget
What kind of entity a rule targets.

Functions

enumerate_config_sources
Enumerate the config sources that would be loaded for a given cwd.
find_project_config
Walk up from start looking for .rippy or .dippy config files.
home_dir
load_file
Parse a single config file and append directives to the list.
parse_action_word
parse_rule
Parse a single config line into a ConfigDirective.