load_file

Function load_file 

pub fn load_file(
    path: &Path,
    directives: &mut Vec<ConfigDirective>,
) -> Result<(), RippyError>
Parse a single config file and append directives to the list.

Errors

Returns RippyError::Config if the file cannot be read or contains invalid syntax.