pub struct FlagAlias {
pub short: String,
pub long: String,
}Expand description
A short ↔ long flag pair discovered from help output.
Fields
short: Stringlong: StringTrait Implementations
Sourceimpl Archive for FlagAlias
impl Archive for FlagAlias
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedFlagAlias
type Archived = ArchivedFlagAlias
The archived representation of this type. Read more
Sourcetype Resolver = FlagAliasResolver
type Resolver = FlagAliasResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
impl Eq for FlagAlias
impl StructuralPartialEq for FlagAlias