HandlerContext

Struct HandlerContext 

pub struct HandlerContext<'a> {
    pub command_name: &'a str,
    pub args: &'a [String],
    pub working_directory: &'a Path,
    pub remote: bool,
    pub receives_piped_input: bool,
    pub cd_allowed_dirs: &'a [PathBuf],
}
Context passed to handlers for classification.

Fields

command_name: &'a strargs: &'a [String]working_directory: &'a Pathremote: boolreceives_piped_input: boolcd_allowed_dirs: &'a [PathBuf]

Extra directories that cd is allowed to navigate to (from config).

Implementations

Source

impl HandlerContext<'_>

pub fn subcommand(&self) -> &str

Get the first argument (typically a subcommand).

pub fn arg(&self, n: usize) -> &str

Get the Nth argument.

pub fn read_file(&self, path: &str) -> Option<String>

Read a file’s contents for informed classification.

Returns None if the file can’t be read (remote mode, missing, too large, binary, or outside the working directory).