pub fn parse_project_sessions(
cwd: &Path,
) -> Result<Vec<SessionCommand>, RippyError>Expand description
Find and parse all session files for the current project.
Errors
Returns RippyError::Parse if session files cannot be read.
pub fn parse_project_sessions(
cwd: &Path,
) -> Result<Vec<SessionCommand>, RippyError>Find and parse all session files for the current project.
Returns RippyError::Parse if session files cannot be read.