pub fn run(args: &SuggestArgs) -> Result<ExitCode, RippyError>Expand description
Run the rippy suggest command.
Errors
Returns RippyError if the database cannot be opened or queried,
or if applying suggestions fails.
pub fn run(args: &SuggestArgs) -> Result<ExitCode, RippyError>Run the rippy suggest command.
Returns RippyError if the database cannot be opened or queried,
or if applying suggestions fails.